{% extends 'app.html' %}
{% block content %}
    <div class="ui main container">
      {% block body %}{% endblock %}
    </div>
    <div class="ui inverted vertical footer segment">
        <div class="ui inverted section divider"></div>

    </div>
{% endblock %}