{% extends 'base.html' %}

{% block title %}Index Page{% endblock %}

{% block body %}
{% for cat, msg in get_flashed_messages(with_categories=true) %}
      <div class="ui {{ cat }} message"><p>{{ msg }}</p></div>
{% endfor %}
<div class="ui grid">
    <div class="six wide column">
<h2>Please sign in, you can try:</h2>

<form action="" class="ui form" method="POST">
  <input class="field username" id="name" name="username"
    placeholder="username" type="text" value=""><br><br>
  <input class="password field" id="password" name="password"
    placeholder="password" type="password" value=""><br><br>
  <input id="submit"  class="ui button primary" name="submit" type="submit" value="Sign In">
</form></div></div>
{% endblock %}
