{% extends 'base.html' %}
{% block title %}

    {{model}}}

{% endblock %}

{% block body %}
{% for cat, msg in get_flashed_messages(with_categories=true) %}
      <div class="ui {{ cat }} message"><p>{{ msg }}</p></div>
{% endfor %}
<div class="ui breadcrumb">
  <a class="section" href="{{url_prefix}}">Admin</a>
  <i class="right angle icon divider"></i>
  <a class="section" href="{{url_prefix}}/{{model}}">{{model.capitalize()}}</a>
  <i class="right angle icon divider"></i>
  <div class="active section">Add {{model.capitalize()}}</div>
</div>

<form class="ui form" action="{{url_prefix}}/{{model}}/add" method="post">
{% for column in columns_names %}
  <div class="field">
    <label>{{column}}</label>
    <input type="text" name="{{column}}" placeholder="{{column}}">
  </div>

  {% endfor %}
  <button class="ui button" type="submit">Submit</button>
</form>
{% endblock %}